@@ -20,7 +20,7 @@ dict1 = n0dict({
         {"a": 4, "b": 5, "c": 6, "value1": 2, "value2": 5},
         {"a": 7, "b": 8, "c": 9, "value1": 3, "value2": 6},
     ],
-})
+}, recursively=True)
 n0debug("dict1")
 # ******************************************************************************
 # Sorted list in dictionary
@@ -31,7 +31,7 @@ dict2 = n0dict({
         {"a": 4, "b": 5, "c": 6, "value1": 2, "value2": 99},    # Single difference in value2
         {"a": 7, "b": 8, "c": 9, "value1": 3, "value2": 6},
     ],
-})
+}, recursively=True)
 # ******************************************************************************
 # Unsorted list in dictionary
 # ******************************************************************************
@@ -42,7 +42,7 @@ dict3 = n0dict({
         {"a": 1, "b": 2, "c": 3, "value1": 1, "value2": 4},     # Changed order [0] -> [2]
         {"a": 1, "b": 2, "c": 3, "value1": 1, "value2": 4},     # Duplicated with [2]
     ],
-})
+}, recursively=True)
 # ******************************************************************************
 def test_SortedLists():
 
